aboutsummaryrefslogtreecommitdiffstats
path: root/lib/private/legacy/OC_Image.php
diff options
context:
space:
mode:
authorSimon L <szaimen@e.mail.de>2022-12-21 20:01:19 +0100
committerSimon L <szaimen@e.mail.de>2022-12-22 09:52:46 +0100
commitbfb3b2af9f07f39b175ee6321f939a8d778499c1 (patch)
tree400484172733f020f7d5336983799c14021e44d3 /lib/private/legacy/OC_Image.php
parentc1a99ca58ffdcf37c7f9aaffdb336de45de98231 (diff)
downloadnextcloud-server-bfb3b2af9f07f39b175ee6321f939a8d778499c1.tar.gz
nextcloud-server-bfb3b2af9f07f39b175ee6321f939a8d778499c1.zip
increase preview_max_memory and make it easier to debug
Signed-off-by: Simon L <szaimen@e.mail.de>
Diffstat (limited to 'lib/private/legacy/OC_Image.php')
-rw-r--r--lib/private/legacy/OC_Image.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/private/legacy/OC_Image.php b/lib/private/legacy/OC_Image.php
index 9ccc6409ba0..d2faae9e24d 100644
--- a/lib/private/legacy/OC_Image.php
+++ b/lib/private/legacy/OC_Image.php
@@ -50,8 +50,8 @@ use OCP\IImage;
*/
class OC_Image implements \OCP\IImage {
- // Default memory limit for images to load (128 MBytes).
- protected const DEFAULT_MEMORY_LIMIT = 128;
+ // Default memory limit for images to load (256 MBytes).
+ protected const DEFAULT_MEMORY_LIMIT = 256;
// Default quality for jpeg images
protected const DEFAULT_JPEG_QUALITY = 80;
@@ -585,7 +585,7 @@ class OC_Image implements \OCP\IImage {
// Assume 32 bits per pixel.
if ($width * $height * 4 > $memory_limit * 1024 * 1024) {
- $this->logger->debug('Image size of ' . $width . 'x' . $height . ' would exceed allowed memory limit of ' . $memory_limit);
+ $this->logger->info('Image size of ' . $width . 'x' . $height . ' would exceed allowed memory limit of ' . $memory_limit . '. You may increase the preview_max_memory in your config.php if you need previews of this image.');
return false;
}